@@ -1,5 +1,6 @@
 from django.db import models
 from django.utils.translation import gettext_lazy as _
+
 from terminusgps.wialon import flags
 
 
@@ -74,3 +75,13 @@ ACCESSMASK_UNIT_SUPER: int = sum(
 )
 
 ACCESSMASK_UNIT_FULL: int = sum([flags.ACCESSFLAG_FULL_ACCESS])
+
+ACCESSMASK_UNIT_MIGRATION: int = sum(
+    [
+        flags.ACCESSFLAG_DELETE_ITEM,
+        flags.ACCESSFLAG_MANAGE_ITEM_ACCESS,
+        flags.ACCESSFLAG_UNIT_DELETE_MESSAGES,
+        flags.ACCESSFLAG_UNIT_MANAGE_CONNECTIVITY,
+        flags.ACCESSFLAG_VIEW_ITEM_BASIC,
+    ]
+)
